*************************************************************
***														  ***
*** 			  	 Replicaton analysis	 			  ***
*** Title: "Climate, flood and attitudes toward violence: ***
***       micro-level evidence from Karamoja, Uganda"	  ***
*** Authors: Von Uexkull, Loy, d'Errico (2023)			  ***
***		Reference author: nina.von_uexkull@pcr.uu.se	  ***
***														  ***
***  This do.file contains the code for replicating the   ***
***  		 models as displayed in the paper             ***
*** 													  ***
*************************************************************

* The analysis is performed using STATA 17 for Windows. 

* Import dataset

clear all
*use "..\dataset.dta" 
 
 
						**************
						* Main paper * 
						**************
						 
 
******************************************************************
* Table 1: Cross-section analysis flood and support for violence *
******************************************************************

* Model 1  
ols_spatial_HAC violence_justified2019 shock_flood2019  abim amudat kaabong kotido moroto napak  constant , lat(a3a2019) lon(a3b2019) timevar(year_fake) panelvar(uhhid) dist(10) lag(0) star  
outreg2 using myreg1.xls, replace ctitle(OLS)    dec(3) pdec(3) 
 
* Model 2
ols_spatial_HAC violence_justified2019 shock_flood2019  pastoralist2016 female19 log_fortransfers_2016  abim amudat kaabong kotido moroto napak   constant, lat(a3a2019) lon(a3b2019) timevar(year_fake) panelvar(uhhid) dist(10) lag(0) star  
 outreg2 using myreg1.xls, append ctitle(OLS)  dec(3) pdec(3) 
 
* Model 3   
ols_spatial_HAC violence_justified2019 shock_flood2019 shock_drought2019 pastoralist2016 female19  log_fortransfers_2016 fcs2019 fatalities_acled2016  abim amudat kaabong kotido moroto napak   constant, lat(a3a2019) lon(a3b2019) timevar(year_fake) panelvar(uhhid) dist(10) lag(0) star  
outreg2 using myreg1.xls, append ctitle(OLS)  dec(3) pdec(3) 
 


**************************************************
* Figure 2: Flood impacts on material conditions * 
**************************************************

* Import dataset
clear all
*use "..\datasetDID.dta" 
 
 
* Crop 
ols_spatial_HAC cropharvest_100kg flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg.xls, replace ctitle(crop) 
estimates store LIB1
	
* TLU
ols_spatial_HAC tlu flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak  constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg.xls, append ctitle(livestock) 
estimates store LIB2
	
* FCS 
ols_spatial_HAC fcs flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg.xls, append ctitle(food consumption)
estimates store LIB3

* Wealth 
ols_spatial_HAC wealthindex flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg.xls,  append ctitle(wealth)
estimates store LIB4
	
* CSI
ols_spatial_HAC csi_mean flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg.xls, append ctitle(days of coping strategies) 
estimates store LIB5
	
* Figure 2
 coefplot(LIB1, label(Crops in 100kg) msymbol(O)) ///
         (LIB2, label(Livestock (TLU)) msymbol(D)) ///
		 (LIB3, label(Food consumption (FCS)) msymbol(T))  ///
		 (LIB4, label(Wealth index) msymbol(S)) ///
         (LIB5, label (Use of coping strategies (CSI)) msymbol(X)), ///
		 keep (DID) xline(0, lcolor(black))  mcolor(black) mlcolor(black) mfcolor(white)  mlstyle(black) graphregion(col(white)) bgcol(white) ciopts(lcol(black))
		 

*********************************************************************
* Figure 3: Flood impact on the subjective assessment of conditions *
*********************************************************************

ols_spatial_HAC absorptive_sri flood_treated time DID pastoralist_livelihood log_fortransfers   abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg2.xls, replace ctitle(absorptive_sri)
estimates store LIB1

ols_spatial_HAC transformative_sri flood_treated time DID pastoralist_livelihood log_fortransfers  abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg2.xls, append ctitle(transformative_sri)
estimates store LIB2
  
ols_spatial_HAC financial_sri flood_treated time DID pastoralist_livelihood log_fortransfers   abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg2.xls, append ctitle(financial_sri)
estimates store LIB3

ols_spatial_HAC political_sri flood_treated time DID pastoralist_livelihood log_fortransfers   abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg2.xls, append ctitle(political_sri) 
estimates store LIB4
 
* Figure 3
coefplot(LIB1, label(absorptive)  msymbol(O))  ///
         (LIB2, label(transformative)  msymbol(D))   ///
		 (LIB3, label(financial)  msymbol(T))   ///
		 (LIB4, label(political)  msymbol(S)), ///
		 keep (DID) xline(0, lcolor(black))  mcolor(black) mlcolor(black) mfcolor(white)  mlstyle(black) graphregion(col(white)) bgcol(white) ciopts(lcol(black))



******************************************************************************
* Table 2 Causal mediation analysis of flood effects on support for violence *
******************************************************************************

clear all
*use "..\dataset.dta" 

drop _merge

* Create globals for control variables
gl controls shock_drought2019 pastoralist2016 female19 log_fortransfers_2016 fatalities_acled2016 abim amudat kaabong kotido moroto napak 

* mediator: TLU
medeff (regress dif_tlu shock_flood2019 $controls ) (probit violence_justified2019 shock_flood2019 dif_tlu $controls ), treat(shock_flood2019) mediate(dif_tlu) sims(1000) seed(1234) vce(boot)

* mediator: CSI
medeff (regress dif_csi shock_flood2019 $controls ) (probit violence_justified2019 shock_flood2019 dif_csi $controls ), treat(shock_flood2019) mediate(dif_csi) sims(1000) seed(1234) vce(boot)

* mediator: Political capital 
medeff (regress change_political_sri shock_flood2019 $controls ) (probit violence_justified2019 shock_flood2019 change_political_sri $controls ), treat(shock_flood2019) mediate(change_political_sri) sims(1000) seed(1234) vce(boot)



***************************************
* Figure 4: Sensitivity analysis plot *
***************************************

* sensitivity analysis (mediator: TLU)  
medsens (regress dif_tlu shock_flood2019 $controls ) (probit violence_justified2019 shock_flood2019 dif_tlu $controls ), med(dif_tlu) treat(shock_flood2019) sims(1000) graph

twoway rarea _med_updelta1 _med_lodelta1 _med_rho, bcolor(gs14) || line _med_delta1 _med_rho, lcolor(black) ytitle("ACME(p)") xtitle("Sensitivity parameter: p")  legend(off) title("TLU") name("tlu", replace) graphregion(color(white))

* sensitivity analysis (mediator: CSI)  
medsens (regress dif_csi shock_flood2019 $controls ) (probit violence_justified2019 shock_flood2019 dif_csi $controls ), med(dif_csi) treat(shock_flood2019) sims(1000) graph

twoway rarea _med_updelta1 _med_lodelta1 _med_rho, bcolor(gs14) || line _med_delta1 _med_rho, lcolor(black) ytitle("ACME(p)") xtitle("Sensitivity parameter: p") legend(off) title("CSI") name("csi", replace) graphregion(color(white))

* sensitivity analysis (mediator: political capital)  
medsens (regress change_political_sri shock_flood2019 $controls ) (probit violence_justified2019 shock_flood2019 change_political_sri $controls ), med(change_political_sri) treat(shock_flood2019) sims(1000) graph

twoway rarea _med_updelta1 _med_lodelta1 _med_rho, bcolor(gs14) || line _med_delta1 _med_rho, lcolor(black) ytitle("ACME(p)") xtitle("Sensitivity parameter: p") legend(off) title("Political capital") name("pol", replace) graphregion(color(white))

* Figure 4
graph combine tlu csi pol, rows(1) cols(3) graphregion(color(white))  plotregion(icolor(white)) ycommon



********************************************************************************


						*****************************
						* Supplementary information *
						*****************************



* Import dataset
clear all
*use "..\dataset_totalsample.dta"  


*********************************************
* Table A9: Alternative dependent variables *
*********************************************

* Stealing justified
ols_spatial_HAC steal_justified2019 shock_flood2019  abim amudat kaabong kotido moroto napak  constant, lat(a3a2019) lon(a3b2019) timevar(year_fake) panelvar(uhhid) dist(10) lag(0) star  
outreg2 using myregsteal.xls, replace ctitle(stealing)   dec(2) pdec(3) 

* Disputes
ols_spatial_HAC disputes_involved_all2019 shock_flood2019  abim amudat kaabong kotido moroto napak  constant, lat(a3a2019) lon(a3b2019) timevar(year_fake) panelvar(uhhid) dist(10) lag(0) star  
outreg2 using myregsteal.xls, append ctitle(disputes)   dec(2) pdec(3) 



***********************************************
* Table A10: Full models, material conditions *
***********************************************

* Import dataset
clear all
*use "..\datasetDID.dta" 
 
 
* Crop 
ols_spatial_HAC cropharvest_100kg flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg.xls, replace ctitle(crop) 
	
* TLU
ols_spatial_HAC tlu flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak  constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg.xls, append ctitle(livestock) 
	
* FCS 
ols_spatial_HAC fcs flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg.xls, append ctitle(food consumption)

* Wealth 
ols_spatial_HAC wealthindex flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg.xls,  append ctitle(wealth)
	
* CSI
ols_spatial_HAC csi_mean flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak con
stant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg.xls, append ctitle(days of coping strategies) 
	
	

*************************************************
* Table A11: Full models, subjective conditions *
*************************************************

*use "..\datasetDID.dta" 

* Absorptive
ols_spatial_HAC absorptive_sri flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg2.xls, replace ctitle(absorptive)

* Transformative
ols_spatial_HAC transformative_sri flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg2.xls, append ctitle(transformative)
 
* Financial
ols_spatial_HAC financial_sri flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg2.xls, append ctitle(financial)

* Political
ols_spatial_HAC political_sri flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg2.xls, append ctitle(political) 
 



*********************************
* Table A12: Transfers received *
*********************************

*use "..\datasetDID.dta" 

* Formal transfers as a dependent variable 
ols_spatial_HAC log_fortransfers flood_treated time DID pastoralist_livelihood  abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg.xls, replace ctitle(log(formal transfers)) 	
   
* Informal transfers as a dependent variable
ols_spatial_HAC log_inftransfers flood_treated time DID pastoralist_livelihood  abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg.xls, append ctitle(log(informal transfers)) 	
	


**********************************************************
* Table A13: Material conditions: same respondent sample *
**********************************************************

*use "..\datasetDID_samerespondent.dta" 

* Crop 
ols_spatial_HAC cropharvest_100kg flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg.xls, replace ctitle(crop) 
	
* TLU
ols_spatial_HAC tlu flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak  constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg.xls, append ctitle(livestock) 
	
* FCS 
ols_spatial_HAC fcs flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg.xls, append ctitle(food consumption)

* Wealth 
ols_spatial_HAC wealthindex flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg.xls,  append ctitle(wealth)
	
* CSI
ols_spatial_HAC csi_mean flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg.xls, append ctitle(days of coping strategies) 
	


************************************************************
* Table A14: Subjective conditions: same respondent sample *
************************************************************

*use "..\datasetDID_samerespondent.dta" 

* Absorptive
ols_spatial_HAC absorptive_sri flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg2.xls, replace ctitle(absorptive_sri)

 * Transformative
ols_spatial_HAC transformative_sri flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg2.xls, append ctitle(transformative_sri)
  
* Financial 
ols_spatial_HAC financial_sri flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg2.xls, append ctitle(financial_sri)

 * Political 
ols_spatial_HAC political_sri flood_treated time DID pastoralist_livelihood log_fortransfers abim amudat kaabong kotido moroto napak constant, lat(a3a) lon(a3b) timevar(year) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg2.xls, append ctitle(political_sri) 

  



********************************
* Table A15: Multinomial logit *
********************************

 *use "..\dataset_totalsample.dta"  

 * MNL 1 
mlogit violence_preference2019 shock_flood2019 abim amudat kaabong kotido moroto napak, baseoutcome(0) vce(cluster a92019)
outreg2 using myreg2.xls, replace ctitle(MNL1) dec(3) pdec(3) 

* MNL 2  
mlogit violence_preference2019 shock_flood2019 pastoralist2016 female19 log_fortransfers_2016 abim amudat kaabong kotido moroto napak, baseoutcome(0) vce(cluster a92019)
outreg2 using myreg2.xls, append ctitle(MNL2) dec(3) pdec(3) 

* MNL 3   
mlogit violence_preference2019 shock_flood2019 pastoralist2016 female19 log_fortransfers_2016 shock_drought2019 fcs2019 fatalities_acled2016  abim amudat kaabong kotido moroto napak, baseoutcome(0) vce(cluster a92019)
outreg2 using myreg2.xls, append ctitle(MNL3)  dec(3) pdec(3) 
 



*******************************
* Table A16: Cross section *
*******************************

*use "..\dataset_totalsample.dta"  

* Change CSI
ols_spatial_HAC violence_justified2019 dif_csi pastoralist2016 female19 log_fortransfers_2016 abim amudat kaabong kotido moroto napak constant, lat(a3a2019) lon(a3b2019) timevar(year_fake) panelvar(uhhid) dist(10) lag(0) star 
outreg2 using myreg2.xls, replace ctitle(OLS)  dec(3) pdec(3) 

* Change TLU 
ols_spatial_HAC violence_justified2019 dif_tlu pastoralist2016 female19 log_fortransfers_2016 abim amudat kaabong kotido moroto napak constant, lat(a3a2019) lon(a3b2019) timevar(year_fake) panelvar(uhhid) dist(10) lag(0) star  
outreg2 using myreg2.xls, append ctitle(OLS)  dec(3) pdec(3) 
 
* Change Politicl capital 
ols_spatial_HAC violence_justified2019 change_political_sri pastoralist2016 female19 log_fortransfers_2016 abim amudat kaabong kotido moroto napak constant, lat(a3a2019) lon(a3b2019) timevar(year_fake) panelvar(uhhid) dist(10) lag(0) star  
outreg2 using myreg2.xls, append ctitle(OLS)  dec(3) pdec(3) 

* Change FCS
ols_spatial_HAC violence_justified2019 dif_fcs pastoralist2016 female19 log_fortransfers_2016 abim amudat kaabong kotido moroto napak constant, lat(a3a2019) lon(a3b2019) timevar(year_fake) panelvar(uhhid) dist(10) lag(0) star  
outreg2 using myreg2.xls, append ctitle(OLS)  dec(3) pdec(3) 
  
	



